PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/quadrature.h File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Variables
quadrature.h File Reference

Go to the source code of this file.

## Variables
double | QUADRATURE_POINTS [98][101]
double | QUADRATURE_WEIGHTS [98][101]

## Detailed Description

Contains Legendre Gauss quadrature points and weights for various grid densities.

## Variable Documentation

double QUADRATURE_POINTS[98][101]

double QUADRATURE_WEIGHTS[98][101]